package com.meshsoftware.appmgmt;

import javax.management.MBeanServer;
import javax.management.ObjectName;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import weblogic.management.MBeanHome;
import javax.management.MBeanServerFactory;
import javax.management.NotificationListener;
/**
 * This util class provides methods to a)create and register an MBean 
 * and b) return a reference to Weblogic MBeanServer  
 */

public class MBeanUtil {
/**
 * Creates And Registers an MBean with an MBean Server
 * @param className the classname of the mbean to be registered
 * @param mbeanServer reference to the MBeanServer
 * @param mbeanName the name of the mbean to be shown on a protocol adapter
 * @param domainName the name of the domain for registration of MBeans
 */
    public static void createAndRegisterMBean(Class className,
        MBeanServer mbeanServer, String mbeanName,
        String domainName) {

        Class clazzToInstantiate = null;
        Object obj = null;
        ClassLoader loader = className.getClassLoader();
        try {
            clazzToInstantiate = loader.loadClass(className.getName());
            obj = clazzToInstantiate.newInstance();
        } catch (ClassNotFoundException e) {
            System.err.println("Class not found:"+className.getName());
        } catch (InstantiationException e) {
            System.err.println("Unable to Instantiate:"+className.
                    getName());
        } catch (IllegalAccessException e) {
            System.err.println("Illegal Access:"+className.getName());
        }
        System.out.println(className.getName()+":MBean is now available for usage.");
        try {
            	ObjectName objName = new ObjectName(domainName+mbeanName);
            	mbeanServer.registerMBean(obj,objName);
            	//If the MBean is a listener type then register it as a Listener
            	System.out.println(className.getName()+" Registered..");
          	} catch (Exception e){
            	System.err.println("Registration failed for MBean:"+className.
                    getName());
        }

    }
/**
 * Returns the MBean Server from the default domain
 * TODO Return the MBean Server from a domain name not default domain 
 * @return the MBean Server
 */
    public static MBeanServer getWeblogicMBeanServer(){
        MBeanServer mbeanServer = null;
        Context ctx  = null;
        MBeanHome home = null;
        try {
            ctx = new InitialContext();
            home = (weblogic.management.MBeanHome) ctx.lookup(weblogic.
                    management.MBeanHome.ADMIN_JNDI_NAME);
            mbeanServer = home.getMBeanServer();
	        ctx.close();
            } catch (NamingException e){
                System.err.println("Unable to retrieve JNDI context"+e.getMessage());
            } finally {
                try {
                    if(ctx != null)
                        ctx.close();
                } catch (NamingException el) {
                    System.err.println("Stale reference to JNDI context"+el.getMessage());
                }
            }
        return mbeanServer;
    }
}



