package com.meshsoftware.appmgmt;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.management.MBeanServer;
import javax.management.ObjectName;
import com.meshsoftware.appmgmt.PerformanceMetrics;
import com.sun.jdmk.comm.HtmlAdaptorServer;

/**
 * 
 * This servlet is loaded during startup and creates, registers the MBeans
 * onto the  application server's MBean Server. This class is also responsible to 
 * initialize and start the HTML adaptor on port 9099.
 * 
 */
public class StartupServlet extends HttpServlet {
/**
 * The domain name under which the MBeans should be registered
 */
private static final String DOMAIN_NAME = "PERFORMANCE";
/**
 * The port number for the HTML Adaptor
 */

private static final int PORT_NUM = 9099;

	/**
	 * Called by the server to handle a GET request. We
	 * don't have the need.
	 * @param req The Http Servlet Request Object containing the client's request
	 * @param resp The Http Servlet Response containing the servlet's 
	 * response to the client
	 * @throws ServletException
	 * @throws IOException
	 */
	public void doGet(HttpServletRequest req, HttpServletResponse resp)
		throws ServletException, IOException {

	}
	/**
	 * Called by the server to handle a POST request. We
	 * don't have the need.
	 * @param req The Http Servlet Request Object containing the client's request
	 * @param resp The Http Servlet Response containing the servlet's 
	 * response to the client
	 * @throws ServletException
	 * @throws IOException
	 */
	public void doPost(HttpServletRequest req, HttpServletResponse resp)
		throws ServletException, IOException {

	}
	/**
	 * Called by the servlet container to indicate that the servlet 
	 * is being placed into service. All the MBeans are created and 
	 * registered during application startup.
	 */
	public void init() throws ServletException {
		super.init();
		MBeanServer mbeanServer = MBeanUtil.getWeblogicMBeanServer();
		setHtmlAdapter(mbeanServer);
    	try {
    		MBeanUtil.createAndRegisterMBean(PerformanceMetrics.class, mbeanServer,
			":name=PerformanceMetrics",DOMAIN_NAME);
    	    } catch (Exception e){
         	System.err.println("Error in creation and registration of MBean" +
                       ":"+e.getMessage());
    	    }
	}
	/**
	 * Start the HTML adaptor 
	 * @param mbeanServer The MBean Server 
	 */
	private void setHtmlAdapter(MBeanServer mbeanServer){
	try {
		HtmlAdaptorServer htmlAdapter = new HtmlAdaptorServer(PORT_NUM);
		mbeanServer.registerMBean((Object)htmlAdapter , new ObjectName(DOMAIN_NAME+":name=htmlAdapter,port=9098"));
		htmlAdapter.start();
		System.out.println("HTML Adaptor started ....");
		} catch(Exception e) {
			System.err.println("Error in starting the HTML Adaptor:"+e.getMessage());
		}
    return;
	}


}



